
 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: MA_ChoroAnno93.sas                           |
   |   TITLE: Draw a choropleth map with and OSM background|
   |          and add annotate using new 9.3 syntax.       |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/
/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";


/* Extract NC only */
/**** Use MAPSGfK maps - Use unprojected lat long degrees ******
data mymap; 
    set mapsgfk.us_states(where=(resolution le 4 and     
                          statecode='NC')); 
    x=long; y=lat; 
run;
**** End of MAPSGFK code *****/

/**** Use MAPS data.  In radians *****/
data rmymap; 
    set maps.states (where=(state=(stfips('NC'))));
    id=state; 
run;

%to_degrees(mymap,rmymap);
/**** End of MAPS code ****/

/* Convert to mercator projection*/
%to_mercator(proj_map,mymap, 0);

/* Cities you want to show on the map */
data mycities;
   input state $ 1-2 city $ 4-20;
cards;
NC RALEIGH
NC GREENSBORO
NC CHARLOTTE
NC WILMINGTON
;
run;

/* Get the lat/long location of each city */
Proc geocode 
   method=city
   data=mycities
   out=gmycities;
run;

/* Set x and y for later use */
data gmycities; 
    set gmycities; 
    x=long; y=lat; 
run;

/* Convert to mercator projection*/
%to_mercator(proj_anno,gmycities, 0);

/* Create annotate data set of dots at locations */
%make_dots(annocity,proj_anno,'RED',3);

/* Use parameters here to turn on the OSM maps */
ods html path=ODSOUT file="ChoroAnno93.html" 
    parameters=("OSMSTYLE"="SASMAPNIK");

/* Only JAVA will work with this syntax */
goptions device  = JAVA;


proc gmap map=proj_map data=proj_map anno=annocity;
   id id;
  choro id/ nolegend ;
run;
quit;
ods html close;
