 /*+-------------------------------------------------------+
   |  SAS Global Forum 2013 Sample                         |
   |  Google-like maps in SAS                              |          
   |                                                       |
   |    NAME: MA_ChoroMapAdv93.sas                         |
   |   TITLE: Choropleth map at county level on MapApplet  |
   |          with Scrollable/zoomable OSM background map  |
   |          using old syntax.  JAVA device only.         |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Google-like Maps in SAS                             |
   | NOTE: Modify all libnames and filenames to your       |
   |       installed path.                                 |
   |                                                       |
   |                                                       |
   |18Jan2013                                              |
   +-------------------------------------------------------+*/
/* Location for HTML output */
filename odsout 'c:\';

/* included macro programs */
%include "c:\SGF2013\macros\mapmacros.sas";

/* import the educational response data for coloring map */
Proc Import OUT=county_data
            DATAFILE="C:\SGF2013\MapApplet\cc07_tabB4.xls"
            DBMS=EXCEL replace;
     range="Main file$A9:M3208";
     getnames=NO;
     mixed=NO;
     scantext=YES;
run;

/* process the input data */
/* only keep lines with a comma (ie, the "county, st" lines) */
data county_data; 
   set county_data;
   length statecode $2 county_name $20;
   format bachelors percentn7.1;
   if index(f1,',')^=0 then do;
      statecode=trim(left(scan(f1,2,',')));
      state=stfips(statecode);
      county_name=scan(f1,1,',');
      bachelors=f6/100;
 
      if county_name='McDowell' then county_name='Mc Dowell';
      output;
   end;
run;

proc sql;
   create table county_data as
   select unique county_data.*, cntyname.county
      from county_data left join maps.cntyname
      on (county_data.state=cntyname.state)
      and (upcase(county_data.county_name)=cntyname.countynm)
      order by statecode, county_name;
quit; 
run;

/* Bucket the data into groups */
data county_data; 
    set county_data;
   bucket=0;
   if bachelors<=.10 then bucket=1;
   else if bachelors<=.15 then bucket=2;
   else if bachelors<=.20 then bucket=3;
   else if bachelors<=.25 then bucket=4;
   else if bachelors<=.30 then bucket=5;
   else if bachelors>.30 then bucket=6;
   length my_html $200;
   my_html='title='||quote(trim(left(county_name))||
       ' county: '||put(bachelors,percentn7.1)
       ||'0d'x||" with bachelor's degree or higher");
run;


/* convert the data to mercator for OSM map */
%to_mercator(proj_data, county_data,0);

goptions gunit=pct htitle=16pt ftitle="albany amt/bold" 
         htext=25pt ftext="albany amt/bold";

/* Create a legend */
legend1 label=(position=top justify=center 
  font="albany amt/bold" height=2
  "Percent of People age >=25, with Bachelor's degree or higher:")
  shape=bar(.05in,.05in) 
  value=(justify=left height=2 font="albany amt/bold"
  '<=10%' '10-15%' '15-20%' '20-25%' '25-30%' '>30%'); 


/* subset NC counties */
data rmymap; 
  set maps.counties(where=(state=(stfips('NC'))));   
run;
/* change data from radians to degrees */
%to_degrees(mymap,rmymap);

/* project map to mercator */
%to_mercator(proj_map, mymap, 0 );

/* Use parameters here to turn on the OSM maps */
ods html path=ODSOUT file="ChoroMapAdv93.html" 
    parameters=("OSMSTYLE"="SASMAPNIK");
goptions ypixels=600 xpixels=800;

/* Only JAVA work with this syntax */
goptions device  = JAVA;


Title 'Education in NC';
proc gmap map=proj_map data=proj_data;
   id state county;
   choro bucket/ legend=legend1 html=my_html;
run;
quit;
ods html close;
Title;
